from dataclasses import dataclass


@dataclass(frozen=True, order=True)
class SfwData:
    wave: str = "wave"
    wink: str = "wink"
    tea: str = "tea"
    bonk: str = "bonk"
    punch: str = "punch"
    poke: str = "poke"
    bully: str = "bully"
    pat: str = "pat"
    kiss: str = "kiss"
    kick: str = "kick"
    blush: str = "blush"
    feed: str = "feed"
    smug: str = "smug"
    hug: str = "hug"
    cuddle: str = "cuddle"
    cry: str = "cry"
    cringe: str = "cringe"
    slap: str = "five"
    glomp: str = "glomp"
    happy: str = "happy"
    hold: str = "hold"
    nom: str = "nom"
    smile: str = "smile"
    throw: str = "throw"
    lick: str = "lick"
    bite: str = "bite"
    dance: str = "dance"
    boop: str = "boop"
    sleep: str = "sleep"
    like: str = "like"
    kill: str = "kill"
    tickle: str = "tickle"
    nosebleed: str = "nosebleed"
    threaten: str = "threaten"
    depression: str = "depression"
    wolf_arts: str = "wolf_arts"
    jahy_arts: str = "jahy_arts"
    neko_arts: str = "neko_arts"
    coffee_arts: str = "coffee_arts"
    wallpaper: str = "wallpaper"
    mobile_wallpaper: str = "mobileWallpaper"



from dataclasses import dataclass

@dataclass(frozen=True, order=True)
class NsfwData:
    ass: str = "ass"
    anal: str = "anal"
    bdsm: str = "bdsm"
    classic: str = "classic"
    cum: str = "cum"
    creampie: str = "creampie"
    manga: str = "manga"
    femdom: str = "femdom"
    hentai: str = "hentai"
    incest: str = "incest"
    masturbation: str = "masturbation"
    public: str = "public"
    ero: str = "ero"
    orgy: str = "orgy"
    elves: str = "elves"
    yuri: str = "yuri"
    pantsu: str = "pantsu"
    pussy: str = "pussy"
    glasses: str = "glasses"
    cuckold: str = "cuckold"
    blowjob: str = "blowjob"
    boobjob: str = "boobjob"
    handjob: str = "handjob"
    footjob: str = "footjob"
    boobs: str = "boobs"
    thighs: str = "thighs"
    ahegao: str = "ahegao"
    uniform: str = "uniform"
    gangbang: str = "gangbang"
    tentacles: str = "tentacles"
    gif: str = "gif"
    nsfw_neko: str = "nsfwNeko"
    nsfw_mobile_wallpaper: str = "nsfwMobileWallpeper"
    zettai_ryouiki: str = "zettaiRyouiki"



import typing as t
from abc import ABC, abstractmethod

from pyhmtai.data.routes.nsfw import NsfwData

TYPES = t.Literal["nsfw", "sfw"]

class HmtaiHttpAware(ABC):
    @abstractmethod
    def request_image(
        self, 
        request_type: t.Literal["nsfw", "sfw"],
        endpoint: NsfwData
    ) -> t.Dict[str, str]:
        ...

    @abstractmethod
    def check_api_status(
        self,
        request_type: t.Literal["nsfw", "sfw"]
    ) -> str:
        ...

class AIOHmtaiHttpAware(ABC):
    @abstractmethod
    async def request_image(
        self,
        request_type: t.Literal["nsfw", "sfw"],
        endpoint: NsfwData
    ) -> t.Dict[str, str]:
        ...

    @abstractmethod
    async def check_api_status(
        self,
        request_type: t.Literal["nsfw", "sfw"]
    ) -> str:
        ...



import aiohttp
import requests
import typing as t
from contextlib import AsyncContextDecorator, ContextDecorator

from pyhmtai.data.routes.nsfw import NsfwData
from pyhmtai.data.routes.sfw import SfwData
from pyhmtai.data.constants import BASE_API_URL
from pyhmtai.api.http import HmtaiHttpAware, AIOHmtaiHttpAware

RequestTypes = t.Literal["nsfw", "sfw"]
Endpoints = t.Union[NsfwData, SfwData]

API_URL = "{base}/{req_type}/{point}"

class HmtaiHttp(HmtaiHttpAware, ContextDecorator):
    _session = requests.Session()

    def __enter__(self):
        return self

    def __exit__(self, *exc):
        return False

    def request_image(self, request_type: RequestTypes, endpoint: Endpoints) -> requests.Response:
        if request_type is not None and endpoint is not None:           
            return self._session.get(API_URL.format(base=BASE_API_URL, req_type=request_type, point=endpoint))

    def check_api_status(self, request_type: RequestTypes) -> str:
        if request_type is not None:
            return self._session.get(f"{BASE_API_URL}/{request_type}").status_code


class AIOHmtaiHttp(AIOHmtaiHttpAware, AsyncContextDecorator):
    async def __aenter__(self):
        return self

    async def __aexit__(self, *exc):
        return False

    async def get(self, url: str) -> aiohttp.ClientResponse:
        session = aiohttp.ClientSession()
        response_data = await session.get(url)

        return response_data


    async def request_image(self, request_type: RequestTypes, endpoint: Endpoints) -> aiohttp.ClientResponse | None:
        if request_type is not None and endpoint is not None:
            we_do_a_little_url = API_URL.format(base=BASE_API_URL, req_type=request_type, point=endpoint)
            return await self.get(url=we_do_a_little_url)

    async def check_api_status(self, request_type: RequestTypes) -> str | None:
        if request_type is not None:
            return (await self.get(f"{BASE_API_URL}/{request_type}")).status



from setuptools import setup, find_packages
import pathlib


HERE = pathlib.Path(__file__).parent

README = (HERE / "README.md").read_text(encoding="utf8")

setup(
	name="pyhmtai",
	version="0.1.6",
	author="MagMigo",
	description="HMtai python port.",
	long_description=README,
	long_description_content_type="text/markdown",
	url="https://github.com/MagM1go/pyhmtai",
	packages=find_packages(),
	python_requires='>=3.7',
)


import typing as t

from pyhmtai.impl.http import HmtaiHttp, AIOHmtaiHttp
from pyhmtai.data.routes.nsfw import NsfwData
from pyhmtai.data.routes.sfw import SfwData
from pyhmtai.data.exceptions import ApiNotAvailable


class PyHMTai:
    _http = HmtaiHttp()

    def nsfw_image(self, endpoint: NsfwData) -> t.Dict[str, str] | None:
        request_type = "nsfw"

        if self._http.check_api_status('nsfw') != 200:
            raise ApiNotAvailable("Api may not working, try later.")
    
        with self._http as api:
            return api.request_image(request_type, endpoint).json()

    def sfw_image(self, endpoint: SfwData) -> t.Dict[str, str] | None:
        request_type = "sfw"

        if self._http.check_api_status('sfw') != 200:
            raise ApiNotAvailable("Api may not working, try later.")

        with self._http as api:
            return api.request_image(request_type, endpoint).json()


class AIOPyHMTai:
    _http = AIOHmtaiHttp()

    async def nsfw_image(self, endpoint: NsfwData) -> t.Dict[str, str]:
        request_type = "nsfw"
        
        if await self._http.check_api_status('nsfw') != 200:
            raise ApiNotAvailable("Api may not working, try later.")
    
        async with self._http as api:
            return await api.request_image(request_type, endpoint)

    async def sfw_image(self, endpoint: SfwData) -> t.Dict[str, str]:
        request_type = "sfw"

        if await self._http.check_api_status('sfw') != 200:
            raise ApiNotAvailable("Api may not working, try later.")

        async with self._http as api:
            return await api.request_image(request_type, endpoint)
